@@ -3,12 +3,12 @@
 
 package Config::Apple::Profile::Payload::Email;
 
-use 5.14.4;
+use 5.10.1;
 use strict;
 use warnings FATAL => 'all';
 use base qw(Config::Apple::Profile::Payload::Common);
 
-our $VERSION = '0.55';
+our $VERSION = '0.87';
 
 use Email::Valid;
 use Readonly;
@@ -338,6 +338,18 @@ I<Optional>
 
 The UUID of the PKCS12 Certificate payload used to decrypt emails.
 
+=head3 C<SMIMEEnablePerMessageSwitch>
+
+I<Optional>
+
+A Boolean.  If true, users will be able to disable S/MIME on emails they send.
+If false, S/MIME signing will be used for all emails, and S/MIME encryption will
+be used whenever possible.
+
+Default is false.
+
+I<Available in iOS 8.0 and later only.>
+
 =head2 Application Interaction
 
 =head3 C<PreventMove>
@@ -575,6 +587,14 @@ Readonly our %payloadKeys => (
             $TargetIOS => '5.0',
         },
     },
+    'SMIMEEnablePerMessageSwitch' => {
+        type => $ProfileBool,
+        description => 'Allow users to disable use of S/MIME when they want.',
+        optional => 1,
+        targets => {
+            $TargetIOS => '8.0',
+        },
+    },
     
     # Application interaction
     'PreventMove' => {
